==> alibabacloud_cloudfw20171207-1.2.4.tar.gz: alibabacloud_cloudfw20171207-1.2.4/ChangeLog.md <==
2023-02-09 Version: 1.2.3
- Add api.
- Add multi account attribute.
- Support vfw invade log download for cfw.
- Fix bugs for flow log memberUid field.
- DescribeIPSRules support DefaultAction as input.
- Supported for Security Group prefixlist.
- Support vswitch.

2022-12-22 Version: 1.2.2
- Hide SourceIP.
- Hide MessageType.

2022-12-08 Version: 1.2.1
- DescribeOutgoingDestinationIP support catagoryId and tagIdNew field.
- DescribeOutgoingDomain support catagoryId and tagIdNew field.

2022-12-08 Version: 1.2.0
- Record return log.
- Support vpc peer.
- DescribeRiskEventGroup add SrcIPTag field.
- Support vpc acl use domain addr book.
- Add a pulibc API.
- Resource change.
- Add DescribeVulnerabilityProtectedList API.
- Add info for CreateVpcFirewallConfigure.
- Add MemberUid for DescribeVpcFirewallDetail.

2022-11-02 Version: 1.1.9
- Automatically generate sdk tasks.

2022-09-28 Version: 1.1.8
- Automatically generate sdk tasks.

2022-09-27 Version: 1.1.7
- Automatically generate sdk tasks.

2022-09-27 Version: 1.1.6
- Automatically generate sdk tasks.

2022-09-08 Version: 1.1.5
- Automatically generate sdk tasks.

2022-07-14 Version: 1.1.4
- Automatically generate sdk tasks.

2022-07-07 Version: 1.1.3
- Auto release new SDK.

2022-04-29 Version: 1.1.2
- 更新防火墙sdk

2022-04-29 Version: 1.1.1
- 更新防火墙python3 sdk

2021-10-19 Version: 1.1.0
- Generated python 2017-12-07 for Cloudfw.

2021-05-06 Version: 1.0.1
- Generated python 2017-12-07 for Cloudfw.

2020-12-30 Version: 1.0.0
- AMP Version Change.

==> alibabacloud_cloudfw20171207-1.2.5.tar.gz: alibabacloud_cloudfw20171207-1.2.5/ChangeLog.md <==
2023-02-23 Version: 1.2.4
- Add precheckStatus field for DescribeTrFirewallsV2List.
- DescribeVpcFirewallPrecheckDetail support TR firewall.
- CreateVpcFirewallPrecheck support TR firewall.

- DescribeLocationInfo support country, province, city structured location information.
- DescribeAssetList add NewResourceTag field.
- Support vuln sync for rd.

2023-02-09 Version: 1.2.3
- Add api.
- Add multi account attribute.
- Support vfw invade log download for cfw.
- Fix bugs for flow log memberUid field.
- DescribeIPSRules support DefaultAction as input.
- Supported for Security Group prefixlist.
- Support vswitch.

2022-12-22 Version: 1.2.2
- Hide SourceIP.
- Hide MessageType.

2022-12-08 Version: 1.2.1
- DescribeOutgoingDestinationIP support catagoryId and tagIdNew field.
- DescribeOutgoingDomain support catagoryId and tagIdNew field.

2022-12-08 Version: 1.2.0
- Record return log.
- Support vpc peer.
- DescribeRiskEventGroup add SrcIPTag field.
- Support vpc acl use domain addr book.
- Add a pulibc API.
- Resource change.
- Add DescribeVulnerabilityProtectedList API.
- Add info for CreateVpcFirewallConfigure.
- Add MemberUid for DescribeVpcFirewallDetail.

2022-11-02 Version: 1.1.9
- Automatically generate sdk tasks.

2022-09-28 Version: 1.1.8
- Automatically generate sdk tasks.

2022-09-27 Version: 1.1.7
- Automatically generate sdk tasks.

2022-09-27 Version: 1.1.6
- Automatically generate sdk tasks.

2022-09-08 Version: 1.1.5
- Automatically generate sdk tasks.

2022-07-14 Version: 1.1.4
- Automatically generate sdk tasks.

2022-07-07 Version: 1.1.3
- Auto release new SDK.

2022-04-29 Version: 1.1.2
- 更新防火墙sdk

2022-04-29 Version: 1.1.1
- 更新防火墙python3 sdk

2021-10-19 Version: 1.1.0
- Generated python 2017-12-07 for Cloudfw.

2021-05-06 Version: 1.0.1
- Generated python 2017-12-07 for Cloudfw.

2020-12-30 Version: 1.0.0
- AMP Version Change.
